@@ -6,7 +6,7 @@ extern "C" {
 }
 
 #[allow(dead_code)]
-pub fn file_exist(file_path: &String) -> bool {
+pub fn file_exist(file_path: String) -> bool {
     let str_i = super::string::DynamicString::from(file_path.as_bytes()).get_index();
     unsafe {
         if FileExist(str_i) == 0 {
@@ -29,7 +29,7 @@ pub fn now_timestamp() -> i64 {
 }
 
 #[allow(dead_code)]
-pub fn print_log(level: PrintLogLevel, str: &String) {
+pub fn print_log(level: PrintLogLevel, str: String) {
     let str_i = super::string::DynamicString::from(str.as_bytes()).get_index();
     unsafe {
         PrintLog(level as i32, str_i);
